pub enum WhirProximityStrategy {
UniqueDecoding,
SplitUniqueList {
m: usize,
list_start_round: usize,
},
ListDecoding {
m: usize,
},
}Variants
UniqueDecoding
Unique decoding regime in every WHIR round.
SplitUniqueList
Unique decoding regime in the initial list_start_round WHIR rounds. Then list decoding
regime with the same proximity radius derived from m (see ListDecoding) for all
subsequent WHIR rounds (0-indices >= list_start_round). Note that a WHIR round
consists of codewords of different degrees with the same rate. The WHIR round changes
when the rate changes.
ListDecoding
List decoding regime in every WHIR round, with the same proximity radius derived from m,
where `m = ceil(sqrt(\rho) / 2 \eta), \eta = 1 - sqrt(\rho) - \delta, where \delta is the
proximity radius.
Implementations
Sourceimpl WhirProximityStrategy
impl WhirProximityStrategy
pub fn initial_round(&self) -> ProximityRegime
pub fn in_round(&self, whir_round: usize) -> ProximityRegime