SystemParams

Struct SystemParams 

pub struct SystemParams {
    pub l_skip: usize,
    pub n_stack: usize,
    pub w_stack: usize,
    pub log_blowup: usize,
    pub whir: WhirConfig,
    pub logup: LogUpSecurityParameters,
    pub max_constraint_degree: usize,
}

Fields

l_skip: usizen_stack: usizew_stack: usize

Maximum number of stacked polynomials (i.e. stacked matrix width). This implies a max stacked cell count of w_stack * 2^(n_stack + l_skip).

log_blowup: usize

-log_2 of the rate for the initial Reed-Solomon code.

whir: WhirConfiglogup: LogUpSecurityParametersmax_constraint_degree: usize

Global max constraint degree enforced across all AIR and Interaction constraints

Implementations

Source

impl SystemParams

pub fn new_for_testing(log_trace_height: usize) -> Self

Parameters for testing traces of height up to 2^log_trace_height with toy security parameters for faster testing.

These parameters should not be used in production!

Source

impl SystemParams

pub fn whir(&self) -> &WhirConfig

Source

impl SystemParams

pub fn logup_pow_bits(&self) -> usize

pub fn k_whir(&self) -> usize

pub fn log_stacked_height(&self) -> usize

pub fn log_final_poly_len(&self) -> usize

pub fn num_whir_rounds(&self) -> usize

pub fn num_whir_sumcheck_rounds(&self) -> usize

pub fn new( log_blowup: usize, l_skip: usize, n_stack: usize, w_stack: usize, log_final_poly_len: usize, folding_pow_bits: usize, mu_pow_bits: usize, proximity: WhirProximityStrategy, security_bits: usize, logup: LogUpSecurityParameters, max_constraint_degree: usize, whir_query_phase_pow_bits: usize, k_whir: usize, ) -> SystemParams

Constructor with many configuration options. Only k_whir, max_constraint_degree, query_phase_pow_bits are preset with constants.

The security_bits is the target bits of security. It is used to select the number of WHIR queries, but does not guarantee the target security level is achieved by the overall protocol using these parameters. Use the soundness calculator to ensure the target security level is met.

This function should only be used for internal cryptography libraries. Most users should instead use preset parameters provided in SDKs.