WhirConfig

Struct WhirConfig 

pub struct WhirConfig {
    pub k: usize,
    pub rounds: Vec<WhirRoundConfig>,
    pub mu_pow_bits: usize,
    pub query_phase_pow_bits: usize,
    pub folding_pow_bits: usize,
    pub proximity: WhirProximityStrategy,
}

Fields

k: usize

Constant folding factor. This means that 2^k terms are folded per round.

rounds: Vec<WhirRoundConfig>mu_pow_bits: usize

Number of bits of grinding before sampling the μ batching challenge.

query_phase_pow_bits: usize

Number of bits of grinding for the query phase of each WHIR round. The PoW bits can vary per round, but for simplicity we use the same number for all rounds.

folding_pow_bits: usize

Number of bits of grinding before sampling folding randomness in each WHIR round. The folding PoW bits can vary per round, but for simplicity (and efficiency of the recursion circuit) we use the same number for all rounds.

proximity: WhirProximityStrategy

Proximity regimes for WHIR rounds. We use only proven error bounds.

Note: this field is not needed by the verifier as it is only used to determine the number of queries in the rounds field. However we store it in WhirConfig for security analysis purposes.

Implementations

Source

impl WhirConfig

pub fn new( log_blowup: usize, log_stacked_height: usize, whir_params: WhirParams, security_bits: usize, ) -> Self

Sets parameters targeting security_bits of provable security (including grinding), using the given proximity regime.

pub fn log_final_poly_len(&self, log_stacked_height: usize) -> usize

pub fn num_whir_rounds(&self) -> usize

pub fn num_sumcheck_rounds(&self) -> usize

pub fn queries( proximity_regime: ProximityRegime, protocol_security_level: usize, log_inv_rate: usize, ) -> usize

Pure function to calculate the number of queries necessary for a given WHIR round.

  • protocol_security_level refers to the target bits of security without grinding.
  • log_inv_rate is the log blowup for the WHIR round we want to calculate the number of queries for.