pub type EngineDeviceCtx<E> = <<E as StarkEngine>::PD as ProverDevice<<E as StarkEngine>::PB, <E as StarkEngine>::TS>>::DeviceCtx;Expand description
Convenience alias for the device context type of a StarkEngine.
pub type EngineDeviceCtx<E> = <<E as StarkEngine>::PD as ProverDevice<<E as StarkEngine>::PB, <E as StarkEngine>::TS>>::DeviceCtx;Convenience alias for the device context type of a StarkEngine.