pub fn calculate_n_logup(l_skip: usize, total_interactions: u64) -> usizeExpand description
Common utility function for computing n_logup parameter in terms of total_interactions,
which is the sum of interaction message counts across all traces, using the lifted trace
heights.
This calculation must be consistent between the prover and verifier and is enforced by the verifier.